import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_route53._jsii
import aws_cdk.aws_route53_patterns._jsii
import aws_cdk.aws_route53_targets._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_deployment._jsii
import aws_cdk.core._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-spa-deploy", "1.67.0", __name__[0:-6], "cdk-spa-deploy@1.67.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
